import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.cloud_assembly_schema._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-route53", "1.50.0", __name__[0:-6], "aws-route53@1.50.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
